# Constraint Modules

## Base Classes
::: fdtdx.constraints.module.ConstraintInterface
::: fdtdx.constraints.module.ConstraintModule

## Value Range Transformations
::: fdtdx.constraints.module.StandardToInversePermittivityRange
::: fdtdx.constraints.module.StandardToCustomRange
::: fdtdx.constraints.module.StandardToPlusOneMinusOneRange

## Material Index Transformations
::: fdtdx.constraints.module.ClosestIndex
::: fdtdx.constraints.module.IndicesToInversePermittivities
